@@ -609,10 +609,13 @@ static PyObject *HandMC_Client_get_behaviors(HandMC_Client *self) {
 
     for (b = HandMC_behaviors; b->name != NULL; b++) {
         uint64_t bval = memcached_behavior_get(self->mc, b->flag);
+        PyObject *x = PyInt_FromLong(bval);
 
-        if (PyDict_SetItemString(retval, b->name, PyInt_FromLong(bval))) {
+        if (x == NULL || PyDict_SetItemString(retval, b->name, x)) {
             goto error;
         }
+
+        Py_DECREF(x);
     }
 
     return retval;
@@ -637,6 +640,7 @@ static PyObject *HandMC_Client_set_behaviors(HandMC_Client *self,
             }
 
             r = memcached_behavior_set(self->mc, b->flag, PyInt_AS_LONG(v));
+            Py_DECREF(v);
             if (r != MEMCACHED_SUCCESS) {
                 PyErr_Format(HandMCExc_MemcachedError,
                              "memcached_behavior_set returned %d", r);
