@@ -1,7 +1,9 @@
 """Tests. They want YOU!!
 
 Basic functionality.
->>> c = handmc.client([test_server])
+>>> c = _pylibmc.client([test_server])
+>>> c.get_behaviors()
+>>> c.set_behaviors(dict(hash=12))
 >>> c.set("test_key", 123)
 True
 >>> c.get("test_key")
@@ -67,14 +69,14 @@ True
 >>>
 """
 
-import handmc
+import _pylibmc
 import socket
 
-test_server = (handmc.server_type_tcp, "localhost", 11211)
+test_server = (_pylibmc.server_type_tcp, "localhost", 11211)
 
 def get_version(addr):
     (type_, host, port) = addr
-    if (type_ != handmc.server_type_tcp):
+    if (type_ != _pylibmc.server_type_tcp):
         raise NotImplementedError("test server can only be on tcp for now")
     else:
         s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
